"""Some useful data structures for problem solving.

Modules
-------

elements:
    Basic elements to use in data structures.

    Classes
    -------
    Number:
        Immutable real numbers.

stacks:
    Stack-like data structures.

    Classes
    -------
    Stack:
        Basic stack data structure.

queues:
    Queue-like data structures.

    Classes
    -------
    Queue:
        Basic queue data structure.
"""
